:py:mod:`byma.iteral.nonstationary.NonStationary`
=================================================

.. py:module:: byma.iteral.nonstationary.NonStationary


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.nonstationary.NonStationary.NonStationary




.. py:class:: NonStationary


   Defines default options for the NonStationary method


